@@ -17,7 +17,7 @@ bannerops = CliCommandType(
 def load_admin_commands(self, _):
     with self.command_group('devops admin banner', command_type=bannerops) as g:
         g.command('list', 'banner_list', table_transformer=transform_banner_table_output)
-        g.command('show', 'banner_show', table_transformer=transform_banner_table_output)
+        g.show_command('show', 'banner_show', table_transformer=transform_banner_table_output)
         g.command('add', 'banner_add', table_transformer=transform_banner_table_output)
         g.command('remove', 'banner_remove')
         g.command('update', 'banner_update', table_transformer=transform_banner_table_output)
